#
# spec file for package spacenavd
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2009,2011,2013 Herbert Graeber
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1140
%define has_systemd 1
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
%endif
Name:           spacenavd
Version:        0.6
Release:        19.1
Summary:        Daemon for 3Dconnexion devices
License:        GPL-3.0-or-later
Group:          Hardware/Other
URL:            http://spacenav.sourceforge.net
Source:         https://github.com/FreeSpacenav/%{name}/archive/%{name}-%{version}.tar.gz
Source1:        spacenavd.8.gz
Source2:        spnavrc
Source3:        xinitrc-%{name}
Source4:        %{name}.service
Patch1:         spacenavd-0.6+git3066072.patch
# PATCH-FIX-UPSTREAM spacenavd-add-blacklist-and-device-ids.patch #4
Patch2:         spacenavd-add-blacklist-and-device-ids.patch
# PATCH-FIX-UPSTREAM spacenavd-add-missing-usbid.patch #12
Patch3:         spacenavd-add-missing-usbid.patch
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
Requires:       xdpyinfo
Supplements:    modalias(usb:v046DpC603d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v046DpC605d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v046DpC606d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v046DpC621d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v046DpC623d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v046DpC625d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v046DpC626d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v046DpC627d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v046DpC628d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v046DpC629d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v046DpC62bd*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v046DpC640d*dc*dsc*dp*ic*isc*ip*)
Supplements:    modalias(usb:v256Fp*d*dc*dsc*dp*ic*isc*ip*)

%description
Spacenavd is a free software replacement user-space driver (daemon)
for 3Dconnexion's 6-degree-of-freedoms input devices. It is
compatible with the original 3dxsrv daemon, and works perfectly with
any program that was written for the 3Dconnexion driver.

%prep
%setup -q -n %{name}-%{name}-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
%configure
make %{?_smp_mflags} opt="%{optflags}"

%install
install -D -m 755 %{name} %{buildroot}%{_sbindir}/%{name}
install -D -m 755 spnavd_ctl %{buildroot}%{_bindir}/spnavd_ctl
install -D -m 644 %{SOURCE1} %{buildroot}%{_mandir}/man8/spacenavd.8.gz
ln -sf spacenavd.8.gz %{buildroot}%{_mandir}/man8/spnavd_ctl.8.gz
install -D -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/spnavrc
install -D -m 755 %{SOURCE3} %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d/%{name}
ln -sf service %{buildroot}%{_sbindir}/rc%{name}
%if 0%{?has_systemd}
install -D -m 644 %{SOURCE4} %{buildroot}%{_unitdir}/%{name}.service
%endif

%post
%fillup_only -n %{name}
%if 0%{?has_systemd}
%service_add_post %{name}.service
%endif

%postun
%if 0%{?has_systemd}
%service_del_postun %{name}.service
%else
%restart_on_update %{name}
%insserv_cleanup
%endif

%pre
%if 0%{?has_systemd}
%service_add_pre %{name}.service
%endif

%preun
%if 0%{?has_systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal %{name}
%endif

%files
%license COPYING
%doc README.md
%{_sbindir}/%{name}
%{_sbindir}/rc%{name}
%{_bindir}/spnavd_ctl
%config(noreplace) %{_sysconfdir}/spnavrc
%if 0%{?has_systemd}
%{_unitdir}/%{name}.service
%endif
%{_mandir}/man8/spacenavd.8%{?ext_man}
%{_mandir}/man8/spnavd_ctl.8%{?ext_man}
%{_sysconfdir}/X11/xinit/

%changelog
* Sat Mar 16 2019 Herbert Graeber <herbert@graeber-clan.de>
- Add two upstream patches for proper handling of device ids:
  * spacenavd-add-blacklist-and-device-ids.patch
  * spacenavd-add-missing-usbid.patch
* Sat Aug 25 2018 herbert@graeber-clan.de
- Add patch spacenavd-0.6+git3066072.patch with some bug fixes und support
  for newer devices:
  * minor formatting fixes old and new, and usage of the LED_AUTO enumeration
    in src/client.c
  * LED state enumeration instead of magic numbers, since it's no longer
    a simple boolean value.
  * improve device information provided by daemon
  * updated readme file
  * replaced the svn $rev$ substitution with git describe falling back to
    git rev-parse HEAD
  * fixed axis detection, and added detection of the number of buttons for USB
    devices on linux
  * Applied Wiedemann's patch (sf#6) to link object files in alphabetical order
  * Added missing include to dev_usb_darwin.c closing bug #10
  * fixed a small bug in device detection which sometimes skipped a single
    character during parsing
  * added rule to match devices with the new 3Dconnexion vendor id (0x256f)
  * Better example-spnavrc descriptions - remove some debugging printfs which
    where commited accidentally previously
  * moved axis remapping before checking deadzones
  * trying to remove devices from Xinput
  * added all the missing options to the example-spnavrc file
  * possible fix for bug #9
  * added code to skip joystick device files while parsing /proc/bus/input/devices
- Drop reproducible.patch
* Sat Aug 25 2018 herbert@graeber-clan.de
- Add modalias supplements for all supported devices
* Sat Aug 25 2018 herbert@graeber-clan.de
- The repository moved to github
- Rerelease of version 0.6
  * added example config file
  * fixed setup_init failing to detect the correct runlevel in some cases.
  * fixed calculation of time periods in motion events.
  * code refactoring to support multiple operating systems.
  * added freebsd and macos x support for serial devices.
  * fixed build when system headers don't define EV_SYN (linux).
  * added dependency tracking in the makefile.
  * added separate sensitivity control for each axis.
  * added separate deadzone control for each axis.
  * added option to avoid grabbing the device.
  * fixed spurious error messages on SIGHUP.
  * added auto-repeat non-zero events option (useful for serial devices).
  * added button number remapping configuration option.
  * added keyboard emulation option.
  * abort if spacenavd is already running.
  * heed DESTDIR env var in makefile install and uninstall targets.
  * merged serial magellan protocol code.
  * added systemd init file under contrib/.
  * merged Ralf Morel's patch for multiple device support.
  * improved XAUTHORITY handling.
  * improved device selection with predicate callback and USB ids.
  * added joystick support.
  * fixed axis remapping for some HID devices.
  * fixed race condition in X detection.
  * applied Christian Ehrlicher's patches fixing a number of memory bugs.
* Wed Feb 14 2018 crrodriguez@opensuse.org
- Remove buildRequires on xorg-x11-devel
* Sat May 27 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build reproducible
  (boo#1041090)
* Sun Oct 30 2016 jengelh@inai.de
- Rectify description, use source URL and avoid sysvinit calls
  under systemd.
* Thu Oct 27 2016 herbert@graeber-clan.de
- Add a manpage taken from debian
* Thu Oct 27 2016 dan.weatherill@cantab.net
- add xdpyinfo package as explicit dependency, it is required for
  the spnavd_ctl script to work properly
* Mon Mar  2 2015 herbert@graeber-clan.de
- Update to version 0.6
- Remove init file
* Sun Sep  8 2013 herbert@graeber-clan.de
- Change license into SPDX format
- Add systemd support
- Spec file cleanup
* Mon Jan 24 2011 herbert@graeber-clan.de
- Update to version 0.5
- Use separate changes file
* Sun Mar 22 2009 herbert@graeber-clan.de
- Added rcspacenavd link
- Fixed xinitrc script
* Sat Mar 21 2009 herbert@graeber-clan.de
- Initial package
- Add new init-script
- Add commented configuration file
- Add xinitrc script
